# pypbt

This library implements functions to write _property based tests_ in
python.

It started as a proof of concept. By now there are still some missing
features:

  - Shrinking
  
  - Generation strategies
  
  - State machines
  
We can not make any promises about them.


## Installation

```
pip install pypbt
```

## Documentation

See [documentation on readthedocs](https://pypbt.readthedocs.io/en/latest/).

## Support

Please [open an issue](https://github.com/cabrero/pypbt/issues) for support.

## License

The project is licensed under the LGPL license.
